@@ -2,18 +2,18 @@ package Test::Text;
 
 use warnings;
 use strict;
+use utf8; # Files and dictionaries might use utf8
+
 use Carp;
 use File::Slurp 'read_file';
 use Text::Hunspell;
-use Encode::Encoder qw(encoder);
 use v5.14;
 
-use version; our $VERSION = qv('0.1.3'); # One with an Spanish dictionary that actually works.
+use version; our $VERSION = qv('0.1.5'); # Using utf8 all the way through
 
 use base 'Test::Builder::Module';
 
 my $CLASS = __PACKAGE__;
-our $word_re = qr/([\w\'áéíóúÁÉÍÓÚñÑçÇºª¿¡üÜ]+)/;
 our @EXPORT= 'just_check';
 
 # Module implementation here
@@ -61,13 +61,12 @@ sub check {
   my $tb= $CLASS->builder;
   my $speller = $self->{'_speller'};
   for my $f ( @{$self->files}) {
-    my $file_content= read_file($f);
-    my @words = split /\s+/, $file_content;
+    my $file_content= read_file($f, binmode => ':utf8');
+    my @words = ($file_content =~ m{\b(\p{L}+)\b}g);
 
     for my $w (@words) {
-      my ($stripped_word) = ( $w =~ $word_re );
-      next if !$stripped_word;
-      $tb->ok( $speller->check( encoder($stripped_word)->latin1),  $stripped_word);
+      next if !$w;
+      $tb->ok( $speller->check( $w),  "'$w'");
     }
   }
 }
